/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.importer.sinfo.parsers;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;
import org.dive4elements.river.importer.Config;
import org.dive4elements.river.importer.ImportRiver;
import org.dive4elements.river.importer.common.AbstractParser;
import org.dive4elements.river.importer.sinfo.importitem.BedMobilityKmLineImport;
import org.dive4elements.river.importer.sinfo.importitem.BedMobilitySeriesImport;
import org.dive4elements.river.model.sinfo.BedMobility;
import org.dive4elements.river.model.sinfo.BedMobilityValue;

/**
 * Reads and parses an bed mobility file
 *
 * @author Matthias Schäfer
 *
 */
public class BedMobilityParser extends AbstractParser<BedMobility, BedMobilityValue, BedMobilityKmLineImport, BedMobilitySeriesImport> {

    /***** FIELDS *****/

    private static final Logger log = Logger.getLogger(BedMobilityParser.class);

    private static final String MOBILE_KEYWORD = "mobil";

    private static final String IMPORT_FILENAME = "Einteilung der Gewässersohle.csv";


    /***** CONSTRUCTORS *****/

    public BedMobilityParser(final File importPath, final File rootRelativePath, final ImportRiver river) {
        super(importPath, rootRelativePath, river);
    }


    /***** METHODS *****/

    @Override
    protected Logger getLog() {
        return log;
    }

    /**
     * Whether this import type shall be skipped
     */
    public static boolean shallSkip() {
        return Config.INSTANCE.skipSInfoBedMobility();
    }

    /**
     * Creates a list of parsers for all bed mobility import files in a directory
     */
    public static List<BedMobilityParser> createParsers(final File importDir, final File relativeDir, final ImportRiver river) {
        final List<BedMobilityParser> parsers = new ArrayList<>();
        final File importFile = new File(importDir, IMPORT_FILENAME);
        if (importFile.exists())
            parsers.add(new BedMobilityParser(importFile, new File(relativeDir, IMPORT_FILENAME), river));
        return parsers;
    }

    @Override
    protected BedMobilitySeriesImport createSeriesImport(final String filename) {
        return new BedMobilitySeriesImport(filename);
    }

    @Override
    protected BedMobilityKmLineImport createKmLineImport(final Double km, final String[] values) {
        return new BedMobilityKmLineImport(km, values[1].equalsIgnoreCase(MOBILE_KEYWORD));
    }

    @Override
    protected boolean handleMetaOther() {
        return super.handleMetaOther();
    }
}
